Crate nickel_lang_package

Crate nickel_lang_package 

Re-exports

pub use manifest::ManifestFile;

Modules

config
error
index
The package index.
lock
Lock files and lock file utilities
manifest
Functionality related to package manifests.
resolve
snapshot
version
This module contains everything to do with version numbers.

Structs

GitDependency
A dependency that comes from a git repository.
IndexDependency
A dependency that comes from the global package index.
PreciseGitPkg
A git package, with a precise version.
PreciseIndexPkg
A package that comes from the global package index, with a precise version.

Enums

Dependency
A source includes the place to fetch a package from (e.g. git or a registry), along with possibly some narrowing-down of the allowed versions (e.g. a range of versions, or a git commit id).
ObjectId
An owned hash identifying objects, most commonly Sha1
PrecisePkg
A precise package version, in a format suitable for putting into a lockfile.
UnversionedDependency
The subtype of Dependency containing just the git and path variants.
UnversionedPrecisePkg
A precise package version, but only the ones that don’t have versions to resolve.