Error

Enum Error 

pub enum Error {
Show 20 variants Io { path: Option<PathBuf>, error: Error, }, LockFileDeserialization { path: PathBuf, error: Error, }, ManifestEval { package: Option<Ident>, files: Files, error: Box<Error>, }, NoProjectDir, RestrictedPath { package_url: Box<Url>, package_commit: ObjectId, package_path: PathBuf, attempted: PathBuf, restriction: PathBuf, }, RelativeGitImport { path: PathBuf, }, Git(Error), InvalidUrl { msg: String, }, InvalidPathInIndexPackage { id: String, inner: RelativePathError, }, InternalManifestError { path: PathBuf, msg: String, }, TempFilePersist { error: PersistError, }, InvalidIndexDep { id: Id, dep: Box<UnversionedDependency>, }, UnknownIndexPackage { id: Id, }, UnknownIndexPackageVersion { id: Id, requested: SemVer, available: Vec<SemVer>, }, DuplicateIndexPackageVersion { id: Id, version: SemVer, }, PackageIndexSerialization { pkg: Package, error: Error, }, PackageIndexDeserialization { error: Error, }, Resolution(Box<ResolveError>), MismatchedManifestPath { id: Id, manifest_dir: PathBuf, }, OtherGit(Error),
}
Errors related to package management.

Variants



Io

Fields

error: Error


LockFileDeserialization

Fields

path: PathBuf
error: Error


ManifestEval

Fields

package: Option<Ident>
files: Files
error: Box<Error>


NoProjectDir



RestrictedPath

Fields

package_url: Box<Url>

The url of the git package that tried the bad import.

package_commit: ObjectId

The git id of the bad package.

package_path: PathBuf

The relative path of the bad package within its git repo.

attempted: PathBuf
restriction: PathBuf


RelativeGitImport

There was an attempt to import a git repository from a relative path, where the package doing the importing wasn’t a path package.

Fields

path: PathBuf


Git(Error)

There was some error interacting with a git repository.



InvalidUrl

Fields



InvalidPathInIndexPackage



InternalManifestError

Fields

path: PathBuf


TempFilePersist

There was an error persisting a temporary file.

Fields



InvalidIndexDep

A package in the index (or, hopefully, a package potentially destined for the index, because packages actually in the index should be validated) tried to depend on a path or git dependency.



UnknownIndexPackage

The package id wasn’t found in the package index.

Fields

id: Id


UnknownIndexPackageVersion

The requested version of package id wasn’t found in the package index.

Fields

id: Id
requested: SemVer
available: Vec<SemVer>


DuplicateIndexPackageVersion

While trying to insert a package in the index, we found that that same package and version was already present.

Fields

id: Id
version: SemVer


PackageIndexSerialization

We failed to serialize the index description of a package.

Fields

error: Error


PackageIndexDeserialization

We failed to deserialize the index description of a package.

Fields

error: Error


Resolution(Box<ResolveError>)



MismatchedManifestPath

Based on the index id, we expected a manifest file to have a path ending with a particular suffix but it didn’t.

Fields

id: Id
manifest_dir: PathBuf


OtherGit(Error)

Some other error interacting with git.

gix’s errors are highly structured, and for many of them we only care about reporting them as strings.