pub enum RelativePathErrorKind {
Absolute,
OutOfBounds,
InvalidUtf8,
}Variants
Absolute
The path was an absolute path, where a relative one was expected.
OutOfBounds
The path pointed to something outside of the containing directory.
InvalidUtf8
The path contains invalid UTF-8.