pub struct RelativePath { /* private fields */ }Expand description
A relative path that has no “parent” components and is convertible to UTF-8.
The UTF-8 requirement comes from the fact that these paths need to be expressible in Nickel package manifests, which are always UTF-8.
Implementations
Sourceimpl RelativePath
impl RelativePath