Resolution

Struct Resolution 

pub struct Resolution {
    pub config: Config,
    pub snapshot: Snapshot,
    pub index: PackageIndex<Shared>,
    pub index_packages: HashMap<Id, Vec<SemVer>>,
}
Stores the result of resolving version constraints to exact versions.

Fields

config: Configsnapshot: Snapshot

The snapshot (of path and git packages) that was used to construct this resolution. Note that path and git packages are not “resolved”; they have fixed versions. The snapshot is only used to collect index dependencies of git and path packages.

index: PackageIndex<Shared>index_packages: HashMap<Id, Vec<SemVer>>

All the index packages in the dependency tree.

Each package id can resolve to multiple versions, but those versions should all fall into disjoint semantic-version buckets.

Implementations

Source

impl Resolution

pub fn precise(&self, dep: &Dependency) -> PrecisePkg

Finds the precise resolved version of this dependency.

Panics

Panics if the dependency was not part of the dependency tree that this resolution was generated for.

pub fn sorted_dependencies( &self, pkg: &PrecisePkg, ) -> Result<Vec<(Ident, Dependency, PrecisePkg)>, Error>

Returns the dependencies of a package.

Panics

Panics if the package was not part of the dependency tree that this resolution was generated for.

pub fn package_map(&self, manifest: &ManifestFile) -> Result<PackageMap, Error>

Returns a package map containing the entire dependency tree.

pub fn dependencies( &self, pkg: &PrecisePkg, ) -> Result<HashMap<Ident, PrecisePkg>, Error>

Returns all the dependencies of a package, along with their package-local names.

pub fn all_packages(&self) -> Vec<PrecisePkg>

Returns all the resolved packages in the dependency tree.