pub struct LockFileDep {
pub name: EntryName,
pub spec: Option<GitDependency>,
}Fields
name: EntryNamespec: Option<GitDependency>For git packages, we store their original git spec in the lock-file, so that if someone changes the spec in the manifest we can tell that we need to re-fetch the repo.
Note that this goes in LockFileDep (which represents the dependency
edge between two entries) rather than LockFileEntry because there can
be multiple git specs that end up resolving to the same git revision.